@@ -1,12 +1,12 @@
-"""Weaviate-specific serializers for GPT Index data structures.
+"""Weaviate-specific serializers for LlamaIndex data structures.
 
-Contain conversion to and from dataclasses that GPT Index uses.
+Contain conversion to and from dataclasses that LlamaIndex uses.
 
 """
 
 import json
 from abc import abstractmethod
-from typing import Any, Dict, Generic, List, Optional, TypeVar
+from typing import Any, Dict, Generic, List, Optional, TypeVar, cast
 
 from gpt_index.data_structs.data_structs import IndexStruct, Node
 from gpt_index.readers.weaviate.utils import (
@@ -94,7 +94,7 @@ class BaseWeaviateIndexStruct(Generic[IS]):
     @classmethod
     @abstractmethod
     def _entry_to_gpt_index(cls, entry: Dict) -> IS:
-        """Convert to gpt index list."""
+        """Convert to LlamaIndex list."""
 
     @classmethod
     def to_gpt_index_list(
@@ -104,7 +104,7 @@ class BaseWeaviateIndexStruct(Generic[IS]):
         vector: Optional[List[float]] = None,
         object_limit: Optional[int] = None,
     ) -> List[IS]:
-        """Convert to gpt index list."""
+        """Convert to LlamaIndex list."""
         validate_client(client)
         class_name = cls._class_name(class_prefix)
         properties = cls._get_common_properties() + cls._get_properties()
@@ -132,12 +132,14 @@ class BaseWeaviateIndexStruct(Generic[IS]):
 
     @classmethod
     @abstractmethod
-    def _from_gpt_index(cls, client: Any, index: IS, class_prefix: str) -> str:
-        """Convert from gpt index."""
+    def _from_gpt_index(
+        cls, client: Any, index: IS, class_prefix: str, batch: Optional[Any] = None
+    ) -> str:
+        """Convert from LlamaIndex."""
 
     @classmethod
     def from_gpt_index(cls, client: Any, index: IS, class_prefix: str) -> str:
-        """Convert from gpt index."""
+        """Convert from LlamaIndex."""
         validate_client(client)
         index_id = cls._from_gpt_index(client, index, class_prefix)
         client.batch.flush()
@@ -180,7 +182,7 @@ class WeaviateNode(BaseWeaviateIndexStruct[Node]):
 
     @classmethod
     def _entry_to_gpt_index(cls, entry: Dict) -> Node:
-        """Convert to gpt index list."""
+        """Convert to LlamaIndex list."""
         extra_info_str = entry["extra_info"]
         if extra_info_str == "":
             extra_info = None
@@ -204,8 +206,10 @@ class WeaviateNode(BaseWeaviateIndexStruct[Node]):
         )
 
     @classmethod
-    def _from_gpt_index(cls, client: Any, node: Node, class_prefix: str) -> str:
-        """Convert from gpt index."""
+    def _from_gpt_index(
+        cls, client: Any, node: Node, class_prefix: str, batch: Optional[Any] = None
+    ) -> str:
+        """Convert from LlamaIndex."""
         node_dict = node.to_dict()
         vector = node_dict.pop("embedding")
         extra_info = node_dict.pop("extra_info")
@@ -224,7 +228,12 @@ class WeaviateNode(BaseWeaviateIndexStruct[Node]):
         # TODO: account for existing nodes that are stored
         node_id = get_new_id(set())
         class_name = cls._class_name(class_prefix)
-        client.batch.add_data_object(node_dict, class_name, node_id, vector)
+
+        # if batch object is provided (via a contexxt manager), use that instead
+        if batch is not None:
+            batch.add_data_object(node_dict, class_name, node_id, vector)
+        else:
+            client.batch.add_data_object(node_dict, class_name, node_id, vector)
 
         return node_id
 
@@ -250,3 +259,19 @@ class WeaviateNode(BaseWeaviateIndexStruct[Node]):
         entries = parsed_result[class_name]
         for entry in entries:
             client.data_object.delete(entry["_additional"]["id"], class_name)
+
+    @classmethod
+    def from_gpt_index_batch(
+        cls, client: Any, nodes: List[Node], class_prefix: str
+    ) -> List[str]:
+        """Convert from gpt index."""
+        from weaviate import Client  # noqa: F401
+
+        client = cast(Client, client)
+        validate_client(client)
+        index_ids = []
+        with client.batch as batch:
+            for node in nodes:
+                index_id = cls._from_gpt_index(client, node, class_prefix, batch=batch)
+        index_ids.append(index_id)
+        return index_ids
