@@ -2,6 +2,10 @@
 
 from gpt_index.vector_stores.chroma import ChromaVectorStore
 from gpt_index.vector_stores.faiss import FaissVectorStore
+from gpt_index.vector_stores.opensearch import (
+    OpensearchVectorClient,
+    OpensearchVectorStore,
+)
 from gpt_index.vector_stores.pinecone import PineconeVectorStore
 from gpt_index.vector_stores.qdrant import QdrantVectorStore
 from gpt_index.vector_stores.simple import SimpleVectorStore
@@ -14,4 +18,6 @@ __all__ = [
     "WeaviateVectorStore",
     "QdrantVectorStore",
     "ChromaVectorStore",
+    "OpensearchVectorStore",
+    "OpensearchVectorClient",
 ]
