@@ -43,7 +43,7 @@ class PineconeVectorStore(VectorStore):
         try:
             import pinecone  # noqa: F401
         except ImportError:
-            raise ValueError(import_err_msg)
+            raise ImportError(import_err_msg)
         self._pinecone_index = cast(pinecone.Index, pinecone_index)
 
         self._pinecone_kwargs = pinecone_kwargs or {}
@@ -97,7 +97,10 @@ class PineconeVectorStore(VectorStore):
         return self._pinecone_index
 
     def query(
-        self, query_embedding: List[float], similarity_top_k: int
+        self,
+        query_embedding: List[float],
+        similarity_top_k: int,
+        doc_ids: Optional[List[str]] = None,
     ) -> VectorStoreQueryResult:
         """Query index for top k most similar nodes.
 
